#!/bin/nawk -f
# Title: Ashtech_2_satdata.awk
# Author: unknown ( could have been Dan jacobson)
# Updated:   John M.Chatwood
#	     March 15th, 2002
#	     COOK20MV
# Updated:   Geoff Davis
#            March 20th, 2005
#            TUIM03MV - Fixes to match pcode satdata file. Spacing is wrong
#            in files generated by this script
#            
# Purpose: This take in a GPS NMEA data stream from the Ashtech ADU-2 reciever
#	mounted above the aft hanger on the small mast on the port side. This
#	script stripps out the $LGZDA string and the $GPGGA string. It takes
#	only the even 1 minute records and outputs them for the  creation of
#	a "satdata" file.
#
# Future Plans:To possibly make an initial OPTION for DObegincruise for logging interval
#		currently set to .5 seconds in the Ashtech. If changed this could fail.
#		We need to align possible cinfigurations and our scripts and programs
# 		so things don't break if a change is needed in the equipment
#

# pcode_2_satdata prints first lines, Ashtech_2_satdata.awk

#06 01 2003      0043 -39 14.4081  11 18.8567            pc06    1.3
#06 01 2003      0044 -39 14.4011  11 18.8513            pc06    1.3

#----
#06 01 2003      0046  -39 14.3871 0011 18.8480            as07    1.0
#06 01 2003      0047  -39 14.3761 0011 18.8520            as07    1.0

#$LGZDA,235700.00,29,06,2001,,
#$GPGGA,064358.50,4802.4895,S,00959.9930,W,1,06,01.4,+00057,M,,M,,*78

#30 06 2001      2356   5 14.4689 -94 59.3075            pc08    1.0
#30 06 2001      2357   5 14.4102 -94 59.2881            pc08    1.0

#08 12 2002      1147 -33  2.1621 -71 37.5351            pc08    1.0
#08 12 2002      1148 -33  2.1623 -71 37.5348            pc08    1.0

#29 12 2002      2352 -33 54.2056  18 25.3933            pc08    0.9
#29 12 2002      2353 -33 54.2056  18 25.3933            pc08    0.9

#23 12 2002      0012 -46 28.5412  -5 17.6777            pc08    0.9
#23 12 2002      0013 -46 28.4480  -5 17.4064            pc08    0.9

#23 12 2002      1640 -44 51.7043   0-55.7802            pc07    1.0
#23 12 2002      1641 -44 51.5939   0-55.5288            pc07    1.0

#ASH
#22 12 2002      0005  -48 29.8584 -011 50.5710            as07    1.0
#22 12 2002      0006  -48 29.7894 -011 50.2891            as07    1.0

#PCODE satdata
#22 12 2002      1051 -47 41.5525  -8 54.5235            pc08    1.2
#22 12 2002      1052 -47 41.4695  -8 54.2650            pc08    1.2

#22 12 2002      1417 -47 23.4891  -8  0.4075            pc07    1.2
#22 12 2002      1418 -47 23.3970  -8  0.1314            pc07    1.2
#22 12 2002      1419 -47 23.3047  -7 59.8556            pc07    1.2
#22 12 2002      1420 -47 23.2114  -7 59.5798            pc07    1.2


BEGIN {
  FS = ","
    day = 0
    month = 0
    year = 0

    printf "%s\n", "06 01 2003      0044 -39 14.4011  11 18.8513            pc06    1.3"
}

{
	if ($1 == "$LGZDA") {
		day = $3
		month = $4
		year = $5
		next
	}
	if ($1 == "$GPGGA") {

		time = $2

		hour = substr ( time, 1, 2)
		minute = substr (time, 3, 2)
		second = substr (time, 5, 2)
		fracsec = substr (time, 8, 2)
	
		if (( second == "00") && ( fracsec == "00")) {

			lat = $3
			lat_hemi = $4

			lat_deg = substr ( lat, 1, 2)
			lat_min = substr ( lat, 3)
			if ( lat_hemi == "S") {
				lat_deg = 0 - lat_deg
				if ( lat_deg == 0) lat_min -= 0
			}

			lon = $5
			lon_hemi = $6
			lon_deg = substr ( lon, 1, 3)
			lon_min = substr ( lon, 4)
			if ( lon_hemi == "W") {
				lon_deg = 0 - lon_deg
				if ( lon_deg == 0) lon_min = 0 - lon_min
			}
			no_sats = $8

			printf "%02d %02d %04d", day, month, year
			printf "      %02d%02d ", hour, minute

#               printf " %02d %07.4f", lat_deg, lat_min
			printf "%02d %07.4f", lat_deg, lat_min

#                printf  " %04d %07.4f ", lon_deg, lon_min
#                        printf  " %3d %07.4f ", lon_deg, lon_min
# G. Davis 2005mar20 - fixed spaces to match PCODE satdata
                        printf  "%3d %07.4f", lon_deg, lon_min
			printf "            as%02d    1.0", no_sats
			printf "\n"
		}
	}
}

END {
}
