#!/bin/perl -w
##############################################################
# File: mb2grd.pl
##############################################################
# Purpose: netcdf grd from mbsystems multibeam file
#
# <Input>
#	-d (debug)
#       -f (mb file format)
#       -i (mb file input)
#       -h (help)
#       -w (write the inf file)
#       -r (meter resolution)
# </Input>
#       NEED: make inf flag ( -inf  -c  -w ?)
#
# Relies On: mbsystems - unix tools
#
# <dependency time=20040229 21:20>
#       <object name=>
#        pwd, which, mbinfo, mbm_grid
#       </object>
# </dependency>
#
##############################################################
#  GDC - SIO - UCDS - 2004
##############################################################
# <Author> Dru Clark </Author>
# <Date> 20040230 </Date>
# <Version> 1.0 </Version>
##############################################################
use strict;
use diagnostics;
use Getopt::Std;
##############################
my $MAX_DEGREES_PER_DAY = 3;  # limits for grid
##############################
# default values
my $debug = 0;
my $prog_name = "mb2grd.pl";
my $NOT_SET = "not_set";
my $mbfile = $NOT_SET;
my $outfile = $NOT_SET;
my $format = "32";
my $make_inf = 0;
my $meter = "250"; #  default value
my $meter_resolution = "$meter/$meter";
##############################
my @lon;
my @lat;
##############################
my $cmd = "_mbgrid.cmd";
my $rm_cmd = "*.cmd";
my $grd = ".grd";
my $sd = ".sd";
my $inf = ".inf";
my $gridpath = "";
my $mbpath = "/usr/local/bin/mbsystem/";
my $gmtpath = "/usr/local/bin/gmt/";
my $pwd = `pwd`;
chomp $pwd;
##############################

$ENV{PATH} = "$mbpath:$gmtpath:/usr/local/bin:/usr/bin";

     #################################
     #################################
     # read in command line arguments
     my %opts = ();
      getopts('f:i:o:r:dhwc', \%opts) || die &usage();

      ## -d
      if(exists($opts{'d'})){
           $debug = 1;
           print "<DEBUG> Debug mode on\n";
           print "<DEBUG> Working directory $pwd \n";
      }

      ## -h
      if(exists($opts{'h'})){
              &usage();
              exit();
      }
      ## -i
      if(exists($opts{'i'})){
              $mbfile = $opts{'i'};
      }
      else{
              &usage();
              die "ERROR: A multibeam file must be specified with -i: Exiting\n";
      }
      ## -r
      if(exists($opts{'r'})){
              $meter = $opts{'r'};
              $meter_resolution = "$meter/$meter";
      }

      ## -f
      if(exists($opts{'f'})){
              $format = $opts{'f'};
      }
            else{
              &usage();
              die "ERROR: A format must be specified with -f (ie 32,56,57): Exiting\n";
      }
      ## -w
      if(exists($opts{'w'})){
              $make_inf = 1;

      }
      ## -c     test
      if(exists($opts{'c'})){

              my $which = `which mbinfo`;
              print "<WHICH> $which \n";

              $which = `which mbm_grid`;
              print "<WHICH> $which \n";

      }

      #################################
      #################################

      # see if the mb file exists
      my $mb_test = &check_mb($mbfile);

      # make inf if flagged
      if ($make_inf) {my $test_val = &make_inf($mbfile); }

      my $inf_test = &check_inf($mbfile);
	      if($inf_test){   if($debug) {print "<DEBUG> INF file exists for $mbfile \n";}}
	      else { if($debug) {print "<DEBUG> WARNING: NO INF file found for $mbfile \n";}}

      &run_grid($mbfile);

##############################################################
##############################################################
# SUBS
##############################################################
##############################################################

##############################################################
# Routine to Create the inf file then write it to ./$mb.inf
##############################################################
sub
make_inf()
{
     my $mb = shift(@_);

     if(-e "$mb$inf") {return 1}
     else {
     		if($debug) {print "<DEBUG> Running mbinfo: $mb \n";}
     # Create and write inf file
     # -G throws out extreme navigation values
     `$mbpath/mbinfo -i$mb -F$format -G  >  $mb$inf `;
     return 1 }

     return 0;
}
##############################################################
##############################################################
sub
check_inf()
{
     my $mb = shift(@_);

     if(-e "$mb$inf") {return 1}
     else {return 0 }
}
##############################################################
##############################################################
sub
check_mb()
{
     my $mb = shift(@_);

     if(-e "$mb") {
     		if($debug) {print "<DEBUG> MB file exists: $mb \n";}
     return 1}
     else {
 		print "ERROR: MB file does not exist: $mb \n";
		exit();
	  }
}
##############################################################
##############################################################
sub
run_grid()
{
  my $mb = shift(@_);

  my $cmd = ".cmd";
  my $mbgrd_cmd = "_mbgrid.cmd";
  my $grd_cmd = ".grd.cmd";
  my $mb1 = ".mb-1";
  my $mbfile_base = `basename $mb`;
  chomp $mbfile_base;

  #--- RUN MBM_GRID
        ##### External calls to mbsystems -
        my $run_string = "$mbpath/mbm_grid -I$mb -O$mbfile_base  -A1 -E$meter_resolution -F$format -G3 -T.3 -W4. ";
        my $run_cmd = "$pwd/$mbfile_base$mbgrd_cmd";
       # my $run_rm = "/bin/rm $mb$cmd";
       # my $run_rm2 = "/bin/rm $rm_cmd";

        if( -e "$mb$grd"){if($debug){print "$mb$grd EXISTS \n"}}
        else
        {
                if($debug) {print "<DEBUG> Running:  $run_string \n";}
                `$run_string`;
                if($debug) {print "<DEBUG> Running:  $run_cmd \n";}
                `$run_cmd`;


                unlink "$mb$cmd";
    		unlink "$mb$grd_cmd";
    		unlink "$mb$mbgrd_cmd";
    		unlink "$mb$mb1";
		unlink glob("$pwd/datalist*");

        }
}
##############################################################
##############################################################
sub
usage()
{
	print "$prog_name Usage: -dfhiow \n";
	print "-d (debug) \n";
	print "-h (help) \n";
        print "-w (write the inf file)\n";
        #print "-o <arg>(output file name) \n";
        print "-f <arg>(mb file format)\n";
        print "-i <arg>(mb file input)\n";
        print "-r <arg> (meter_resolution)\n\n";
        print "Example: $prog_name -i<mbfile> -f32 -r100 -w \n";

}
##############################################################
##############################################################
# END
